##  Affected Fields
### All Fact Sheet Types
Key | Old Value | New Value
---|---|---
relToParent | Parents | Parent
lifecycle:phaseIn | Phase in | Phase In
lifecycle:phaseOut | Phase out | Phase Out
lifecycle:endOfLife | End of life | End of Life


### Application Fact Sheet
Key | Old Value | New Value
---|---|---
lxStatusSSO | Single Sign On - Availability | Single Sign-On - Availability
lxSsoProvider | Single Sign On - Available Providers | Single Sign-On - Available Providers


### Business Context Fact Sheet
Key | Old Value | New Value
---|---|---
category | Warning type | Warning Type
warningSubType | Warning subtype | Warning Subtype
warningCriticality | Warning criticality | Warning Criticality


### Interface Fact Sheet
Key | Old Value | New Value
---|---|---
dataFlowDirection | Data flow direction | Data Flow Direction


### Transformation Fact Sheet (Legacy)
Key | Old Value | New Value
---|---|---
yearlyTailCost | Annual follow-up cost | Annual Follow-Up Cost
relativeStartDate | Relative start date | Relative Start Date
budgetAfterPlanning | Budget after Planning | Budget After Planning


### Relations
Relation | Key | Old Value | New Value
---|---|---|---
Business Capability / Transformation (legacy) | relBusinessCapabilityToTransformation | Improved By | Improved by
Business Capability / Objective | relBusinessCapabilityToObjective | Improved By | Improved by
IT Component / Tech Category | itComponentTechnologyStackRelation:supportType | Support type | Support Type
Business Capability / Objective | relBusinessCapabilityToObjective:supportType | Support type | Support Type
Transformation Requires (legacy) | requiresTransformationRelation:supportType | Support type | Support Type
IT Component / User Group | itComponentUserGroupRelation:numberOfUsers | Number of users | Number of Users
IT Component / Organization | itComponentOrganizationRelation:numberOfUsers | Number of users | Number of Users
IT Component / User Group | itComponentUserGroupRelation:usageType | Usage type | Usage Type
IT Component / Organization | itComponentOrganizationRelation:usageType | Usage type | Usage Type


